from setuptools import setup

setup(
    name='panjing',
    version='2.1',
    packages=['panjing'],
    url='https://github.com/newpanjing',
    license='Apache Licene 2.0',
    author='panjing',
    author_email='newpanjing@icloud.com',
    description='panjing core'
)
